@@ -24,7 +24,7 @@ Readonly my $FALSE   => 0;
 Readonly my $EMPTY   => q{};
 Readonly my $NL      => "\n";
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 our %DEFAULT_PROCESSORS = (
   pre       => \&_pre,
@@ -347,7 +347,7 @@ File::Process - process text files with customer handlers
 
  my ($lines, $info) = process_file($file, process => sub { 
      my ($fh, $lines, $args, $line) = @_;
-     return uc($line);
+     return uc $line;
     });
 
 =head1 DESCRIPTION
@@ -375,9 +375,9 @@ the drudgery out of writing a simple text processor. It is most effect
 when used on relatively small files.
 
 In it's most basic form the class will return all of the lines in a
-text file. The class exports 1 method (C<process_file>) which uses
-four subroutines that you can override or use in conjunction with your
-processors.
+text file. The class exports 1 method (C<process_file>) which invokes
+multiple subroutines that you can override or use in conjunction with
+your custom processors.
 
 =head1 METHODS AND SUBROUTINES
 
@@ -469,10 +469,13 @@ The default processors are described below.
 
 =head3 pre(file, options)
 
-The default C<pre> processor opens the file and returns a file handle,
-a reference to a array that will be used to store the lines. The
-return should be a tuple that contains the file handle and a reference
-to an array that will be used to store each processed line of the file.
+The default C<pre> processor opens the file and returns a file handle
+and a reference to an array that will be used to store the lines. If
+you provide your own C<pre> process it should also return a tuple that
+contains the file handle and a reference to an array that will be used
+to store each processed line of the file. I<Note that you don't have
+to adhere to this contract if your downstream processors don't require
+the same returns.>
 
 =over 5
 
